import sys

DEFAULT_MERGED_BRANCH_NAME = "flexlate-output"
DEFAULT_TEMPLATE_BRANCH_NAME = "flexlate-templates"

PY10 = sys.version_info >= (3, 10)
